summaryrefslogtreecommitdiffstats
path: root/libkdeedu/kdeeduplot/kplotwidget.h
diff options
context:
space:
mode:
Diffstat (limited to 'libkdeedu/kdeeduplot/kplotwidget.h')
-rw-r--r--libkdeedu/kdeeduplot/kplotwidget.h9
1 files changed, 5 insertions, 4 deletions
diff --git a/libkdeedu/kdeeduplot/kplotwidget.h b/libkdeedu/kdeeduplot/kplotwidget.h
index 5ed550ec..2545ff83 100644
--- a/libkdeedu/kdeeduplot/kplotwidget.h
+++ b/libkdeedu/kdeeduplot/kplotwidget.h
@@ -40,16 +40,17 @@ class TQPixmap;
class KDE_EXPORT KPlotWidget : public TQWidget {
Q_OBJECT
+ TQ_OBJECT
public:
/**@short Constructor. Sets the primary x and y limits in data units.
*@param x1 the minimum X value in data units
*@param x2 the maximum X value in data units
*@param y1 the minimum Y value in data units
*@param y2 the maximum Y value in data units
*@param parent the parent widget
*@param name name label for the KPlotWidget
*/
- KPlotWidget( double x1=0.0, double x2=1.0, double y1=0.0, double y2=1.0, TQWidget *parent=0, const char* name=0 );
+ KPlotWidget( double x1=0.0, double x2=1.0, double y1=0.0, double y2=1.0, TQWidget *tqparent=0, const char* name=0 );
/**Destructor (empty)
*/
@@ -99,7 +100,7 @@ public:
*@param i the index of th item to be replaced
*@param o pointer to the replacement KPlotObject
*/
- virtual void replaceObject( int i, KPlotObject *o ) { ObjectList.replace( i, o ); }
+ virtual void replaceObject( int i, KPlotObject *o ) { ObjectList.tqreplace( i, o ); }
/**@return the number of KPlotObjects in the list
*/
@@ -212,7 +213,7 @@ public:
KPlotAxis LeftAxis;
protected:
- /**@short the paint event handler, executed when update() or repaint() is called.
+ /**@short the paint event handler, executed when update() or tqrepaint() is called.
*/
virtual void paintEvent( TQPaintEvent* /* e */ );
@@ -40,16 +40,17 @@ class TQPixmap;
*@param y1 the minimum Y value in data units
*@param y2 the maximum Y value in data units
- *@param parent the parent widget
+ *@param tqparent the tqparent widget
*@param name name label for the KPlotWidget
*/